Page 121 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 121

Home

    As could be expected, the U. S. State Department
    opposed any investigation into the Mexico-American
    scandal. The tragedy in Mexico, and other similar events
    supported by the State Department throughout the 20th
    century, indicate that the plans of the trustees of the
    Carnegie Endowment for International Peace to control
    United States foreign policy had indeed become a reality.

    In the light of the circumstances, the ability of the
    people of Mexico to retain their Christian heritage is a
    tribute to their civilization. That they continue to come

    across the border into the United states by the millions is
    a sure sign that the socialist wreckers of their nation still
    control Mexico.

    At the same time that the ground-work for a war
    against religion in Mexico was being laid, a war against
    religion was getting under way in the country that was to
    become the Union of Soviet Socialist Republics
    (U.S.S.R.). In many respects, the background of events
    leading up to, and during, the horror that occurred in the
    Soviet Union was similar to that which occurred in

    The seeds of revolution had been planted in Russia as
    early as the eighteenth century by Illuminated Free
    Masonry moving into Russia from Germany and France.
    The scholar Barruel (writing in 1798) had this to say

    116

    The Secret Side of History

    Mexico and France.

    about French involvement: